/// <reference types="node" />
import type { CompileError as ICompileError } from '@astrojs/parser';
import { ServerRuntime as SnowpackServerRuntime, SnowpackConfig, SnowpackDevServer } from 'snowpack';
import { z } from 'zod';
import type { AstroConfig, GetStaticPathsArgs, GetStaticPathsResult, ManifestData, RSSFunctionArgs, RuntimeMode } from './@types/astro';
import { ConfigManager } from './config_manager.js';
import { LogOptions } from './logger.js';
export interface AstroRuntimeConfig {
    astroConfig: AstroConfig;
    cache: {
        staticPaths: Record<string, GetStaticPathsResult>;
    };
    logging: LogOptions;
    mode: RuntimeMode;
    snowpack: SnowpackDevServer;
    snowpackRuntime: SnowpackServerRuntime;
    snowpackConfig: SnowpackConfig;
    configManager: ConfigManager;
    manifest: ManifestData;
}
declare type LoadResultSuccess = {
    statusCode: 200;
    contents: string | Buffer;
    contentType?: string | false;
    rss?: {
        data: any[] & RSSFunctionArgs;
    };
};
declare type LoadResultNotFound = {
    statusCode: 404;
    error: Error;
};
declare type LoadResultError = {
    statusCode: 500;
} & ({
    type: 'parse-error';
    error: ICompileError;
} | {
    type: 'config-error';
    error: z.ZodError;
} | {
    type: 'ssr';
    error: Error;
} | {
    type: 'not-found';
    error: ICompileError;
} | {
    type: 'unknown';
    error: Error;
});
export declare type LoadResult = LoadResultSuccess | LoadResultNotFound | LoadResultError;
export interface AstroRuntime {
    runtimeConfig: AstroRuntimeConfig;
    getStaticPaths: (component: string, mod: any, args: GetStaticPathsArgs) => Promise<GetStaticPathsResult>;
    load: (rawPathname: string | undefined) => Promise<LoadResult>;
    shutdown: () => Promise<void>;
}
export interface RuntimeOptions {
    mode: RuntimeMode;
    logging: LogOptions;
}
/** Core Astro runtime */
export declare function createRuntime(astroConfig: AstroConfig, { mode, logging }: RuntimeOptions): Promise<AstroRuntime>;
export {};
